@@ -6,7 +6,7 @@ use strict;
 # use Debug::ShowStuff::ShowVar;
 
 # version
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 =head1 NAME
 
@@ -246,6 +246,11 @@ Initial release
 
 Fixed bug: incorrect number of test in test plan.
 
+=item Version 0.12    April 25, 2014
+
+Fixed error in META.yml.
+
+
 =back
 
 =cut
\ No newline at end of file
